package org.noritan.textconverter;

/**
 * A concrete class of <code>{@link TextConverter}</code>
 * to prepend leader strings to each lines.
 *
 * @author noritan
 * @version 1.0
 */

public class ImportConverter extends NullConverter {
  static private final String DEFAULT_LEADER = "> ";
  private final String leader;

  /**
   * Construct a default <code>{@link ImportConverter}</code>
   * with a default leader.
   * The default constructor provides an
   * object with a default leader string.
   */
  public ImportConverter() {
    this(DEFAULT_LEADER);
  }

  /**
   * Construct a <code>{@link ImportConverter}</code>
   * with a leader string specified by the parameter.
   *
   * @param leader leader string prepended to each lines.
   */
  public ImportConverter(String leader) {
    this.leader = leader;
  }

  /**
   * Convert a line into a line.
   * Prepend a <code>leader</code> string for each lines.
   *
   * @param line A <code>{@link String}</code> object describing a line.
   * This parameter is provided by
   * the super-class <code>{@link NullConverter}</code>
   * No terminater at the end of line is included.
   * @return converted <code>{@link String}</code> line associating
   * with a <code>line</code> specified by the parameter.
   */
  protected String convertALine(String line) {
    return leader + line;
  }

  public String toString() {
    return "IMPORT-\"" + leader + "\"";
  }
}
