package org.noritan.textconverter;

import java.io.IOException;
import java.io.Reader;
import java.io.Writer;

/**
 * This describes a text document converter.
 * Any converter can be used to convert a text document
 * into another text document.
 *
 * @author noritan
 * @version 1.0
 */

public interface TextConverter {
  /**
   * Convert a text document from <code>{@link Reader}</code>
   * into <code>{@link Writer}</code>.
   *
   * @param reader <code>{@link Reader}</code> object to be used
   * to read a text document which will be converted.
   * @param writer <code>{@link Writer}</code> object to be used
   * to write a converted text document.
   * @throws IOException throwed if any kind of ERROR were found
   * in a conversion process.
   */
  public void convert(Reader reader, Writer writer)
      throws IOException;
}
