package org.noritan.textconverter;

import java.io.IOException;
import java.io.Reader;
import java.io.StringReader;
import java.io.StringWriter;

import javax.swing.border.Border;
import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

/**
 * <p>Title: </p>
 * <p>Description: </p>
 * <p>Copyright: Copyright (c) noritan</p>
 * <p>Organization: NO</p>
 * @author noritan
 * @version 1.0
 */

public class TextConverterApplet
    extends JApplet
{
  private boolean isStandalone = false;
  private JLabel statusBarLabel = new JLabel();
  private JPanel controlPane = new JPanel();
  private JSplitPane documentPane = new JSplitPane();
  private JTextArea textBeforeConversion = new JTextArea();
  private JTextArea textAfterConversion = new JTextArea();
  private JButton convertButton = new JButton();
  private Border beforeConversionBorder;
  private Border afterConversionBorder;
  private GridBagLayout controlLayout = new GridBagLayout();
  private JScrollPane paneBeforeConversion = new JScrollPane();
  private JScrollPane paneAfterConversion = new JScrollPane();
  private JComboBox converterComboBox = new JComboBox();

  private TextConverter converter;

  private static final TextConverter converterList[] = {
      new NullConverter(),
      new ImportConverter(),
      new ImportConverter("noritan> "),
      new Base64Converter("SHIFT_JIS"),
      new Base64Converter("ISO2022JP"),
  };
  private JMenuBar menuBar = new JMenuBar();
  private JMenu fileMenu = new JMenu();
  private JMenu formatMenu = new JMenu();
  private JMenu helpMenu = new JMenu();
  private JMenuItem fileExitMenuItem = new JMenuItem();
  private JCheckBoxMenuItem formatReverseMenuItem = new JCheckBoxMenuItem();
  private JRadioButtonMenuItem formatDecodeMenuItem = new JRadioButtonMenuItem();
  private JRadioButtonMenuItem formatEncodeMenuItem = new JRadioButtonMenuItem();
  private ButtonGroup buttonGroup1 = new ButtonGroup();

  //Get a parameter value
  public String getParameter(String key, String def) {
    return isStandalone ? System.getProperty(key, def) :
        (getParameter(key) != null ? getParameter(key) : def);
  }

  //Construct the applet
  public TextConverterApplet() {
  }

  //Initialize the applet
  public void init() {
    try {
      jbInit();
    }
    catch (Exception e) {
      e.printStackTrace();
    }
  }

  //Component initialization
  private void jbInit()
      throws Exception {
    beforeConversionBorder =
        BorderFactory.createCompoundBorder(
        BorderFactory.createTitledBorder(
        BorderFactory.createLineBorder(Color.black),
        "BEFORE"
        ),
        BorderFactory.createCompoundBorder(
        BorderFactory.createEmptyBorder(0, 5, 5, 5),
        BorderFactory.createLineBorder(Color.black, 2)
        ));
    afterConversionBorder =
        BorderFactory.createCompoundBorder(
        BorderFactory.createTitledBorder(
        BorderFactory.createLineBorder(Color.black),
        "AFTER"
        ),
        BorderFactory.createCompoundBorder(
        BorderFactory.createEmptyBorder(0, 5, 5, 5),
        BorderFactory.createLineBorder(Color.black, 2)
        ));
    statusBarLabel.setBorder(BorderFactory.createLoweredBevelBorder());
    statusBarLabel.setText("STATUS BAR");
    this.setSize(new Dimension(640, 480));
    textBeforeConversion.setFont(new java.awt.Font("Monospaced", 0, 12));
    textBeforeConversion.setText("BEFORE CONVERSION");
    textAfterConversion.setFont(new java.awt.Font("Monospaced", 0, 12));
    textAfterConversion.setText("AFTER CONVERSION");
    convertButton.setText("CONVERT");
    convertButton.setVerticalAlignment(javax.swing.SwingConstants.CENTER);
    convertButton.setVerticalTextPosition(javax.swing.SwingConstants.CENTER);
    convertButton.addActionListener(new java.awt.event.ActionListener()
    {
      public void actionPerformed(ActionEvent e) {
        convertButton_actionPerformed(e);
      }
    });
    controlPane.setLayout(controlLayout);
    documentPane.setOrientation(JSplitPane.VERTICAL_SPLIT);
    documentPane.setResizeWeight(0.5);
    paneBeforeConversion.setBorder(beforeConversionBorder);
    paneAfterConversion.setBorder(afterConversionBorder);
    converterComboBox.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(ActionEvent e) {
        converterComboBox_actionPerformed(e);
      }
    });
    fileMenu.setText("File");
    formatMenu.setText("Format");
    helpMenu.setText("Help");
    fileExitMenuItem.setText("Exit");
    fileExitMenuItem.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(ActionEvent e) {
        fileExitMenuItem_actionPerformed(e);
      }
    });
    formatReverseMenuItem.setText("Reverse");
    formatDecodeMenuItem.setText("DECODE");
    formatEncodeMenuItem.setText("ENCODE");
    documentPane.add(paneAfterConversion, JSplitPane.RIGHT);
    documentPane.add(paneBeforeConversion, JSplitPane.LEFT);
    paneBeforeConversion.getViewport().add(textBeforeConversion, null);
    paneAfterConversion.getViewport().add(textAfterConversion, null);
    this.getContentPane().add(statusBarLabel, BorderLayout.SOUTH);
    this.getContentPane().add(controlPane, BorderLayout.EAST);
    controlPane.add(
        convertButton,
        new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0
            ,GridBagConstraints.CENTER, GridBagConstraints.NONE,
            new Insets(10, 10, 10, 10), 0, 0)
    );
    controlPane.add(
        converterComboBox,
        new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
            ,GridBagConstraints.CENTER, GridBagConstraints.NONE,
            new Insets(10, 10, 10, 10), 0, 0)
    );
    this.getContentPane().add(documentPane, BorderLayout.CENTER);
    menuBar.add(fileMenu);
    menuBar.add(formatMenu);
    menuBar.add(helpMenu);
    this.setJMenuBar(menuBar);
    fileMenu.add(fileExitMenuItem);
    formatMenu.add(formatReverseMenuItem);
    formatMenu.add(formatDecodeMenuItem);
    formatMenu.add(formatEncodeMenuItem);
    buttonGroup1.add(this.formatDecodeMenuItem);
    buttonGroup1.add(this.formatEncodeMenuItem);
  }

  //Start the applet
  public void start() {
    converterComboBox.removeAllItems();
    for (int i = 0; i < converterList.length; i++) {
      converterComboBox.addItem(converterList[i]);
    }
    converterComboBox.setSelectedIndex(0);
    converterComboBox.invalidate();
  }

  //Stop the applet
  public void stop() {
  }

  //Destroy the applet
  public void destroy() {
  }

  //Get Applet information
  public String getAppletInfo() {
    return "Applet Information";
  }

  //Get parameter info
  public String[][] getParameterInfo() {
    return null;
  }

  //Main method
  public static void main(String[] args) {
    TextConverterApplet applet = new TextConverterApplet();
    applet.isStandalone = true;
    JFrame frame = new JFrame();
    //EXIT_ON_CLOSE == 3
    frame.setDefaultCloseOperation(3);
    frame.setTitle("Text Converter Applet Frame");
    frame.getContentPane().add(applet, BorderLayout.CENTER);
    applet.init();
    applet.start();
    frame.setSize(640, 500);
    Dimension d = Toolkit.getDefaultToolkit().getScreenSize();
    frame.setLocation((d.width - frame.getSize().width) / 2,
        (d.height - frame.getSize().height) / 2);
    frame.setVisible(true);
  }

  //static initializer for setting look & feel
  static {
    try {
      //UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
      //UIManager.setLookAndFeel(UIManager.getCrossPlatformLookAndFeelClassName());
    }
    catch (Exception e) {
    }
  }

  private void convertButton_actionPerformed(ActionEvent e) {
    Reader reader = new StringReader(textBeforeConversion.getText());
    StringWriter writer = new StringWriter();
    try {
      statusBarLabel.setText("Converting with " + getConverter());
      getConverter().convert(reader, writer);
      textAfterConversion.setText(writer.getBuffer().toString());
      statusBarLabel.setText("Finished conversion with " + getConverter());
    }
    catch (IOException ex) {
      // Exception in .convert(Reader, Writer)
      ex.printStackTrace();
      statusBarLabel.setText("Error in conversion with " + getConverter());
    }
  }

  public void setConverter(TextConverter converter) {
    this.converter = converter;
  }

  public TextConverter getConverter() {
    return this.converter;
  }

  private void converterComboBox_actionPerformed(ActionEvent e) {
    int index = converterComboBox.getSelectedIndex();
    if ((index < 0) || (index >= converterList.length)) return;
    setConverter((TextConverter)converterComboBox.getSelectedItem());
    statusBarLabel.setText("Ready for conversion with " + getConverter());
  }

  void fileExitMenuItem_actionPerformed(ActionEvent e) {
    System.exit(0);
  }
}
